# martini_sour

#![license](https://img.shields.io/github/license/marrink-lab/polyply_1.0)

## Functionality
Help setup titratable martini simulations and analyze them.

## Contributions
The code development of polyply is done 
on [github]. Contributions are welcome as [bug reports] and [pull requests] from everyone.

## License

Martini_sour is distributed under the Apache 2.0 license.

    Copyright 2021 University of Groningen

	Licensed under the Apache License, Version 2.0 (the "License");
	you may not use this file except in compliance with the License.
	You may obtain a copy of the License at

		http://www.apache.org/licenses/LICENSE-2.0

	Unless required by applicable law or agreed to in writing, software
	distributed under the License is distributed on an "AS IS" BASIS,
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	See the License for the specific language governing permissions and
	limitations under the License.

The full text of the license is available in the source repository.

[github]: https://github.com/marrink-lab/martini_sour
[bug reports]: https://github.com/marrink-lab/martini_sour/issues
[pull requests]: https://github.com/marrink-lab/martini_sour/pulls
[pipdoc]: https://packaging.python.org/tutorials/installing-packages/#installing-packages
